@@ -536,12 +536,6 @@ sub setLastBlock {
     $class->{"ParserHelpers"}->{"lastBlock"} = $lastBlock;
 }
 
-sub getLastBlock {
-    my ($class) = @_;
-    my $lastBlock = $class->{"ParserHelpers"}->{"lastBlock"};
-    return $lastBlock;
-}
-
 sub nextTokens {
     my ($class) = @_;
     my @tokens = @{$class->{"ParserHelpers"}->{"Tokens"}};
@@ -560,11 +554,10 @@ sub printError {
 
     my $currentClassName = $class->getCurrentClass();
     my $currentFunctionName = $class->getCurrentFunction();
-    my $lastBlock = $class->getLastBlock();
     my $nextTokens = $class->nextTokens();
 
     print "Error at: \nclassName: ", $currentClassName, "\nfunctionName: "
-          , $currentFunctionName, "\nlastCompiledBlock: ", $lastBlock, "\nnextTokens: ", $nextTokens, "\n";
+          , $currentFunctionName, "\nnextTokens: ", $nextTokens, "\n";
 }
 
 1;
@@ -958,10 +951,422 @@ sub PackageWithConstructor {
 
     my $currentToken = $class->getToken();
     if($currentToken->{"type"} eq "Object") {
-        ####
-    }
+        $packageWithConstructor .= $currentToken->{"value"};
+    } else {
+		$class->putToken($currentToken);
+		return 0;
+	}
+
+	$currentToken = $class->getToken();
+    if($currentToken->{"value"} eq "=") {
+        $packageWithConstructor .= $currentToken->{"value"};
+    } else {
+		$class->putToken($currentToken);
+		return 0;
+	}
+
+	my $packageName = $class->PackageName();
+	if($packageName) {
+		$packageWithConstructor .= $packageName;
+	} else {
+		return 0;
+	}
+
+	$currentToken = $class->getToken();
+    if($currentToken->{"value"} eq ".") {
+        $packageWithConstructor .= $currentToken->{"value"};
+    } else {
+		$class->putToken($currentToken);
+		return 0;
+	}
+
+	my $constructor = $class->Constructor();
+	if($constructor) {
+		$packageWithConstructor .= $packageName;
+	} else {
+		return 0;
+	}
+
+	$currentToken = $class->getToken();
+    if($currentToken->{"value"} eq "(") {
+        $packageWithConstructor .= $currentToken->{"value"};
+    } else {
+		$class->putToken($currentToken);
+		return 0;
+	}
+
+	my $objectParameters = $class->ObjectParameters();
+	if($objectParameters) {
+		$packageWithConstructor .= $objectParameters;
+	} else {
+		return 1;
+	}
+
+	$currentToken = $class->getToken();
+    if($currentToken->{"value"} eq ")") {
+        $packageWithConstructor .= $currentToken->{"value"};
+    } else {
+		$class->putToken($currentToken);
+		return 0;
+	}
+
+	return $packageWithConstructor;
 }
 
+sub ObjectParameters {
+	my ($class) = @_;
+
+	my $packageParams = $class->PackageParams();
+	if($packageParams) {
+		return $packageParams;
+	}
+
+	my $parameters = $class->Parameters();
+	if($parameters) {
+		return $parameters;
+	}
+
+	return 0;
+}
+
+sub PackageParams {
+	my ($class) = @_;
+	my $packageParams = "";
+
+	my $keyValue = $class->KeyValue();
+	if($keyValue) {
+		$packageParams .= $keyValue;
+	} else {
+		return 0;
+	}
+
+	my $comma = $class->Comma();
+	if($comma) {
+		$packageParams .= $comma;
+	} else {
+		return $packageParams;
+	}
+
+	my $rightPackageParams = $class->PackageParams();
+	if($rightPackageParams) {
+		$packageParams .= $rightPackageParams;
+	} else {
+		return 0;
+	}
+
+	return $packageParams;
+}
+
+sub PackageName {
+	my ($class) = @_;
+	my $packageName = "";
+
+	my $packageDir = $class->PackageDir();
+	if($packageDir) {
+		$packageName .= $packageDir;
+	} else {
+		return 0;
+	}
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "ObjectColon") {
+		$packageName .= $currentToken->{"value"};
+	} else {
+		return $packageName;
+	}
+
+	my $rightpackageName = $class->PackageName();
+	if($rightpackageName) {
+		$packageName .= $rightpackageName;
+	} else {
+		return 0;
+	}
+
+	return $packageName;
+}
+
+sub PackageWithConstructor {
+	my ($class) = @_;
+	my $packageWithConstructor = "";
+
+	my $packageName = $class->PackageName();
+	if($packageName) {
+		$packageWithConstructor .= $packageName;
+	} else {
+		return 0;
+	}
+
+	my $qw = $class->QW();
+	if($qw) {
+		$packageWithConstructor .= $qw;
+	} else {
+		return 1;
+	}
+
+	return $packageWithConstructor;
+}
+
+sub QW {
+	my ($class) = @_;
+	my $qw = "";
+
+	my $dot = $class->Dot();
+	if($dot) {
+		$qw .= $dot;
+	} else {
+		return 0;
+	}
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"value"} eq "(") {
+		$qw .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	my $functionList = $class->FunctionList();
+	if($functionList) {
+		$qw .= $functionList;
+	} else {
+		return 0;
+	}
+
+	$currentToken = $class->getToken();
+	if($currentToken->{"value"} eq ")") {
+		$qw .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $qw;
+}
+
+sub FunctionList {
+	my ($class) = @_;
+	my $functionList = "";
+
+	my $functionName = $class->FunctionName();
+	if($functionName) {
+		$functionList .= $functionName;
+	} else {
+		return 0;
+	}
+
+	my $comma = $class->Comma();
+	if($comma) {
+		$functionList .= $comma;
+	} else {
+		return $functionList;
+	}
+
+	my $rightFunctionName = $class->FunctionList();
+	if($rightFunctionName) {
+		$functionList .= $rightFunctionName;
+	} else {
+		return 0;
+	}
+
+	return $functionList;
+}
+
+sub Constructor {
+	my ($class) = @_;
+	my $constructor = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "Symbol") {
+		$constructor .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $constructor;
+}
+
+sub Object {
+	my ($class) = @_;
+	my $object = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "Symbol") {
+		$object .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $object;
+}
+
+sub PackageDir {
+	my ($class) = @_;
+	my $packageDir = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "Symbol") {
+		$packageDir .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $packageDir;
+}
+
+sub Function {
+	my ($class) = @_;
+	my $function = "";
+
+	my $tokenFunction = $class->TokenFunction();
+	if($tokenFunction) {
+		$function .= $tokenFunction;
+	} else {
+		return 0;
+	}
+
+	my $functionName = $class->FunctionName();
+	if($functionName) {
+		$function .= $functionName;
+	} else {
+		return 0;
+	}
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"value"} eq "(") {
+		$function .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	my $functionParamList = $class->FunctionParamList();
+	if($functionParamList) {
+		$function .= $functionParamList;
+	} else {
+		return 0;
+	}
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"value"} eq ")") {
+		$function .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	my $codeBlock = $class->CodeBlock();
+	if($codeBlock) {
+		$function .= $codeBlock;
+	} else {
+		return 0;
+	}
+
+	return $function;
+}
+
+sub FunctionName {
+	my ($class) = @_;
+	my $functionName = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "Symbol") {
+		$functionName .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $functionName;
+}
+
+sub FunctionParamList {
+	my ($class) = @_;
+	my $functionParamList = "";
+
+	my $emptyParamList = $class->EmptyParamList();
+	if($emptyParamList) {
+		return $emptyParamList;
+	}
+
+	my $functionParams = $class->FunctionParams();
+	if($functionParams) {
+		return $functionParams;
+	}
+
+	return 0;
+}
+
+sub EmptyParamList {
+	my ($class) = @_;
+	return "";
+}
+
+sub FunctionParams {
+	my ($class) = @_;
+	my $functionParams = "";
+
+	my $arg = $class->Arg();
+	if($arg) {
+		$functionParams .= $arg;
+	} else {
+		return 0;
+	}
+
+	my $comma = $class->Comma();
+	if($arg) {
+		$functionParams .= $comma;
+	} else {
+		return $functionParams;
+	}
+
+	my $rightFunctionParams = $class->FunctionParams();
+	if($rightFunctionParams) {
+		$functionParams .= $rightFunctionParams;
+	} else {
+		return 0;
+	}
+
+	return $rightFunctionParams;
+}
+
+sub Arg {
+	my ($class) = @_;
+	my $arg = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "Symbol") {
+		$arg .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $arg;
+}
+
+sub CodeBlock {
+	my ($class) = @_;
+	my $codeBlock = "";
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "{") {
+		$codeBlock .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	my $blocks = $class->Blocks();
+	if($blocks) {
+		$codeBlock .= $blocks;
+	} else {
+		return 0;
+	}
+
+	my $currentToken = $class->getToken();
+	if($currentToken->{"type"} eq "}") {
+		$codeBlock .= $currentToken->{"value"};
+	} else {
+		return 0;
+	}
+
+	return $codeBlock;
+}
+
+
 1;
 
 package Lang::HL::Syntax;
@@ -970,7 +1375,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my ($class) = @_;
@@ -993,16 +1398,12 @@ __END__
 
 =head1 NAME
 
-Lang::HL::Syntax - Perl extension for blah blah blah
+Lang::HL::Syntax - Syntax Check for HL
 
 =head1 SYNOPSIS
 
 	$> hle <directory>
 
-=head1 DESCRIPTION
-
-This module is under development.
-
 =head1 AUTHOR
 
 Rajkumar Reddy
